==> musashi-1.0.0.tar.gz: musashi-1.0.0/cmd/Help/ja/xt2htmlHelp.h <==

#include "commonHelp.h"
/*============================================================================*/
/* ޥɥإ,man,musahi GUI ̥å                           */
/*============================================================================*/
/*----------------------------------------------------------------------------*/
/* ޥɤΥȥ                                                         */
/* ޥɥإפκǽιԤɽ                                             */
/*----------------------------------------------------------------------------*/
#define HELPT "xmlTablehtmlؤѴ"

/*----------------------------------------------------------------------------*/
/* ѥ᡼                                                                 */
/* ޥɥإפ USAGE:Ȥ" XXXT"ɽ ex)-k ̾ꥹ*/
/* flagΥץϥޥɥإפOPTIONS)Ȥɽ ex)-z : ɸϤΰ*/
/*----------------------------------------------------------------------------*/
/*-i*/
#define INFT C_INFT
#define INFC C_INFC

/*-o*/
#define OTFT C_OTFT
#define OTFC C_OTFC

/*-z*/
#define ZIPT C_ZIPT
#define ZIPC C_ZIPC

/*----------------------------------------------------------------------------*/
/*                                                                        */
/* ޥɥإפSUMMARY:Ȥɽ                                     */
/* HTMLإפmanˤϡHELPDξ˷礹ɽ                   */
/*----------------------------------------------------------------------------*/
#define HELPS "xmlTablehtmlѴ"

/*----------------------------------------------------------------------------*/
/*                                                                          */
/*----------------------------------------------------------------------------*/
#define HELPE "\
xt2html -i dat.xt -o rsl.html
"

/*----------------------------------------------------------------------------*/
/* ȥޥ(ɬޤǶڤꡢѤʤ)                           */
/*----------------------------------------------------------------------------*/
#define HELPR "txt2xt,xt2xml,xt2txt,xml2xt"

/*----------------------------------------------------------------------------*/
/* ԤˤĤ                                                               */
/* ޥɥإפˤɽʤ                                             */
/*----------------------------------------------------------------------------*/
#define HELPA C_HELPA

/*----------------------------------------------------------------------------*/
/* Хݡ                                                               */
/* ϿХޥɥإפBUG REPORT:ɽ롣                  */
/* Ͽʤ(#define HELPB "")ɽʤ                           */
/*----------------------------------------------------------------------------*/
#define HELPB C_HELPB

/*----------------------------------------------------------------------------*/
/* ۡڡ                                                               */
/* ϿХޥɥإפINFORMATION:ɽ롣                 */
/* Ͽʤ(#define HELPH "")ɽʤ                           */
/*----------------------------------------------------------------------------*/
#define HELPH C_HELPH

==> musashi-1.0.1.tar.gz: musashi-1.0.1/cmd/Help/ja/xt2htmlHelp.h <==

#include "commonHelp.h"
/*============================================================================*/
/* ޥɥإ,man,musahi GUI ̥å                           */
/*============================================================================*/
/*----------------------------------------------------------------------------*/
/* ޥɤΥȥ                                                         */
/* ޥɥإפκǽιԤɽ                                             */
/*----------------------------------------------------------------------------*/
#define HELPT "xmlTablehtmlؤѴ"

/*----------------------------------------------------------------------------*/
/* ѥ᡼                                                                 */
/* ޥɥإפ USAGE:Ȥ" XXXT"ɽ ex)-k ̾ꥹ*/
/* flagΥץϥޥɥإפOPTIONS)Ȥɽ ex)-z : ɸϤΰ*/
/*----------------------------------------------------------------------------*/
/*-k*/
#define KEYT "̾ꥹ"
#define KEYC "ܤƱͤιԤϰĤΥɽ"

/*-R*/
#define RITT "ͤܥꥹ"
#define RITC "ǻꤷܤͤϱͤɽ"
#define RITF NULL

/*-C*/
#define CNTT "·ܥꥹ"
#define CNTC "ǻꤷܤͤ·ɽ"
#define CNTF NULL

/*-q*/
#define SEQT C_SEQT
#define SEQC C_SEQC

/*-i*/
#define INFT C_INFT
#define INFC C_INFC

/*-o*/
#define OTFT C_OTFT
#define OTFC C_OTFC

/*-z*/
#define ZIPT C_ZIPT
#define ZIPC C_ZIPC

/*-T*/
#define TMPT C_TMPT
#define TMPC C_TMPC

/*----------------------------------------------------------------------------*/
/*                                                                        */
/* ޥɥإפSUMMARY:Ȥɽ                                     */
/* HTMLإפmanˤϡHELPDξ˷礹ɽ                   */
/*----------------------------------------------------------------------------*/
#define HELPS "xmlTablehtmlѴ"

/*----------------------------------------------------------------------------*/
/*                                                                          */
/*----------------------------------------------------------------------------*/
#define HELPE "\
xt2html -i dat.xt -o rsl.html
"

/*----------------------------------------------------------------------------*/
/* ȥޥ(ɬޤǶڤꡢѤʤ)                           */
/*----------------------------------------------------------------------------*/
#define HELPR "txt2xt,xt2xml,xt2txt,xml2xt"

/*----------------------------------------------------------------------------*/
/* ԤˤĤ                                                               */
/* ޥɥإפˤɽʤ                                             */
/*----------------------------------------------------------------------------*/
#define HELPA C_HELPA

/*----------------------------------------------------------------------------*/
/* Хݡ                                                               */
/* ϿХޥɥإפBUG REPORT:ɽ롣                  */
/* Ͽʤ(#define HELPB "")ɽʤ                           */
/*----------------------------------------------------------------------------*/
#define HELPB C_HELPB

/*----------------------------------------------------------------------------*/
/* ۡڡ                                                               */
/* ϿХޥɥإפINFORMATION:ɽ롣                 */
/* Ͽʤ(#define HELPH "")ɽʤ                           */
/*----------------------------------------------------------------------------*/
#define HELPH C_HELPH
